---
title: '[2024년 02월] 개인정보처리방침 개정 변경 안내'
category: 공지사항
seo:
  title: '[2024년02월]개인정보처리방침 개정 변경 안내'
  description: |
    항상 포트원을 이용해주시는 고객 여러분께 진심으로 감사드립니다. 
    2024년 02월 21일 아래와 같이 개인정보처리방침이 변경됨을 사전 안내 드립니다.
    공고일 : 2024.02.14(수)
    시행일 : 2024.02.21(수)
  keywords:
    - 개인정보처리방침
    - 공지사항
tags:
  - 공통
  - 공지사항
pgCompanies:
  - null
searchTags:
  - 개인정보처리방침
  - 개인정보
  - 공지
datetime: 2024-02-26T15:00:00.000Z
---

안녕하세요.

포트원입니다. 항상 포트원을 이용해 주시는 고객 여러분께 진심으로 감사드립니다.

2024년 02월 21일 아래와 같이 개인정보처리방침이 변경됨을 사전 안내드립니다.

- 공고일 : 2024.02.14(수)
- 시행일 : 2024.02.21(수)

### 변경 내용

- 수집하는 개인정보의 항목 내용 수정 및 추가



- 개인정보 처리의 위탁업무내용 및 수탁업체 추가



- 개인정보 처리의 위탁내용 추가

